<?php

namespace BooklyServiceExtras\Frontend\Modules\ModernBookingForm;

use Bookly\Lib as BooklyLib;
use BooklyServiceExtras\Lib;

/**
 * Class Ajax
 *
 * @package BooklyPro\Frontend\Modules\ModernBookingForm
 */
class Ajax extends BooklyLib\Base\Ajax
{
    public static function modernBookingFormGetExtras()
    {
        $service_id = self::parameter( 'service_id' );

        $service = BooklyLib\Entities\Service::find( $service_id );

        $extras = array();
        if ( $service->getType() === BooklyLib\Entities\Service::TYPE_SIMPLE ) {
            foreach ( Lib\ProxyProviders\Local::findByServiceId( $service_id ) as $extra ) {
                $extras[] = self::_prepareExtras( $extra );
            }
        } elseif ( $service->isCollaborative() || $service->isCompound() ) {
            foreach ( $service->getSubServices() as $sub_service ) {
                foreach ( Lib\ProxyProviders\Local::findByServiceId( $sub_service->getId() ) as $extra ) {
                    $extras[] = self::_prepareExtras( $extra );
                }
            }
        }

        wp_send_json_success( $extras );
    }

    private static function _prepareExtras( Lib\Entities\ServiceExtra $extra )
    {
        $extra_result = array(
            'id' => $extra->getId(),
            'price' => $extra->getPrice(),
            'min_quantity' => $extra->getMinQuantity(),
            'max_quantity' => $extra->getMaxQuantity(),
            'title' => $extra->getTranslatedTitle(),
            'print_price' => BooklyLib\Utils\Price::format( $extra->getPrice() ),
            'print_duration' => BooklyLib\Utils\DateTime::secondsToInterval( $extra->getDuration() ),
        );
        if ( $extra->getAttachmentId() && $image_attributes = wp_get_attachment_image_src( $extra->getAttachmentId(), 'thumbnail' ) ) {
            $extra_result['img'] = $image_attributes[0];
        }

        return $extra_result;
    }

    /**
     * @inheritDoc
     */
    protected static function permissions()
    {
        return array( '_default' => 'anonymous' );
    }
}